@@ -14,12 +14,13 @@ use crate::{
         UnitErrorDescription,
         displayer::DisplayUnitKind,
         events::{
-            ExecutionDescription, ExecutionResult, FailureStatus, StressIndex, TestEvent,
-            TestEventKind, UnitKind,
+            ChildExecutionOutputDescription, ChildOutputDescription, ExecutionDescription,
+            ExecutionResultDescription, FailureDescription, StressIndex, TestEvent, TestEventKind,
+            UnitKind,
         },
     },
     run_mode::NextestRunMode,
-    test_output::{ChildExecutionOutput, ChildOutput},
+    test_output::ChildSingleOutput,
 };
 use debug_ignore::DebugIgnore;
 use indexmap::IndexMap;
@@ -82,7 +83,7 @@ impl<'cfg> MetadataJunit<'cfg> {
                     TestCaseStatus::success()
                 } else {
                     let (kind, ty) =
-                        non_success_kind_and_type(mode, UnitKind::Script, run_status.result);
+                        non_success_kind_and_type(mode, UnitKind::Script, &run_status.result);
                     let mut testcase_status = TestCaseStatus::non_success(kind);
                     testcase_status.set_type(ty);
                     testcase_status
@@ -153,7 +154,7 @@ impl<'cfg> MetadataJunit<'cfg> {
                         ..
                     } => {
                         let (kind, ty) =
-                            non_success_kind_and_type(mode, UnitKind::Test, first_status.result);
+                            non_success_kind_and_type(mode, UnitKind::Test, &first_status.result);
                         let mut testcase_status = TestCaseStatus::non_success(kind);
                         testcase_status.set_type(ty);
                         (testcase_status, first_status, retries)
@@ -161,7 +162,7 @@ impl<'cfg> MetadataJunit<'cfg> {
                 };
 
                 for rerun in reruns {
-                    let (kind, ty) = non_success_kind_and_type(mode, UnitKind::Test, rerun.result);
+                    let (kind, ty) = non_success_kind_and_type(mode, UnitKind::Test, &rerun.result);
                     let mut test_rerun = TestRerun::new(kind);
                     test_rerun
                         .set_timestamp(rerun.start_time)
@@ -322,11 +323,11 @@ impl fmt::Display for SuiteKey<'_> {
 fn non_success_kind_and_type(
     mode: NextestRunMode,
     kind: UnitKind,
-    result: ExecutionResult,
+    result: &ExecutionResultDescription,
 ) -> (NonSuccessKind, String) {
     match result {
-        ExecutionResult::Fail {
-            failure_status: FailureStatus::Abort(_),
+        ExecutionResultDescription::Fail {
+            failure: FailureDescription::Abort { .. },
             leaked: true,
         } => (
             NonSuccessKind::Failure,
@@ -335,15 +336,15 @@ fn non_success_kind_and_type(
                 DisplayUnitKind::new(mode, kind),
             ),
         ),
-        ExecutionResult::Fail {
-            failure_status: FailureStatus::Abort(_),
+        ExecutionResultDescription::Fail {
+            failure: FailureDescription::Abort { .. },
             leaked: false,
         } => (
             NonSuccessKind::Failure,
             format!("{} abort", DisplayUnitKind::new(mode, kind)),
         ),
-        ExecutionResult::Fail {
-            failure_status: FailureStatus::ExitCode(code),
+        ExecutionResultDescription::Fail {
+            failure: FailureDescription::ExitCode { code },
             leaked: true,
         } => (
             NonSuccessKind::Failure,
@@ -352,8 +353,8 @@ fn non_success_kind_and_type(
                 DisplayUnitKind::new(mode, kind),
             ),
         ),
-        ExecutionResult::Fail {
-            failure_status: FailureStatus::ExitCode(code),
+        ExecutionResultDescription::Fail {
+            failure: FailureDescription::ExitCode { code },
             leaked: false,
         } => (
             NonSuccessKind::Failure,
@@ -362,14 +363,16 @@ fn non_success_kind_and_type(
                 DisplayUnitKind::new(mode, kind),
             ),
         ),
-        ExecutionResult::Timeout {
+        ExecutionResultDescription::Timeout {
             result: SlowTimeoutResult::Fail,
         } => (
             NonSuccessKind::Failure,
             format!("{} timeout", DisplayUnitKind::new(mode, kind)),
         ),
-        ExecutionResult::ExecFail => (NonSuccessKind::Error, "execution failure".to_owned()),
-        ExecutionResult::Leak {
+        ExecutionResultDescription::ExecFail => {
+            (NonSuccessKind::Error, "execution failure".to_owned())
+        }
+        ExecutionResultDescription::Leak {
             result: LeakTimeoutResult::Pass,
         } => (
             NonSuccessKind::Error,
@@ -378,7 +381,7 @@ fn non_success_kind_and_type(
                 DisplayUnitKind::new(mode, kind),
             ),
         ),
-        ExecutionResult::Leak {
+        ExecutionResultDescription::Leak {
             result: LeakTimeoutResult::Fail,
         } => (
             NonSuccessKind::Error,
@@ -387,8 +390,8 @@ fn non_success_kind_and_type(
                 DisplayUnitKind::new(mode, kind),
             ),
         ),
-        ExecutionResult::Pass
-        | ExecutionResult::Timeout {
+        ExecutionResultDescription::Pass
+        | ExecutionResultDescription::Timeout {
             result: SlowTimeoutResult::Pass,
         } => {
             unreachable!("this is a failure status")
@@ -452,7 +455,7 @@ impl TestcaseOrRerun<'_> {
 }
 
 fn set_execute_status_props(
-    exec_output: &ChildExecutionOutput,
+    exec_output: &ChildExecutionOutputDescription<ChildSingleOutput>,
     store_stdout_stderr: bool,
     mut out: TestcaseOrRerun<'_>,
 ) {
@@ -465,29 +468,29 @@ fn set_execute_status_props(
 
     if store_stdout_stderr {
         match exec_output {
-            ChildExecutionOutput::Output {
-                output: ChildOutput::Split(split),
+            ChildExecutionOutputDescription::Output {
+                output: ChildOutputDescription::Split { stdout, stderr },
                 ..
             } => {
-                if let Some(stdout) = &split.stdout {
+                if let Some(stdout) = stdout {
                     out.set_system_out(stdout.as_str_lossy());
                 } else {
                     out.set_system_out(STDOUT_NOT_CAPTURED);
                 }
-                if let Some(stderr) = &split.stderr {
+                if let Some(stderr) = stderr {
                     out.set_system_err(stderr.as_str_lossy());
                 } else {
                     out.set_system_err(STDERR_NOT_CAPTURED);
                 }
             }
-            ChildExecutionOutput::Output {
-                output: ChildOutput::Combined { output },
+            ChildExecutionOutputDescription::Output {
+                output: ChildOutputDescription::Combined { output },
                 ..
             } => {
                 out.set_system_out(output.as_str_lossy())
                     .set_system_err(STDOUT_STDERR_COMBINED);
             }
-            ChildExecutionOutput::StartError(_) => {
+            ChildExecutionOutputDescription::StartError(_) => {
                 out.set_system_out(PROCESS_FAILED_TO_START)
                     .set_system_err(PROCESS_FAILED_TO_START);
             }
@@ -499,10 +502,11 @@ fn set_execute_status_props(
 mod tests {
     use super::*;
     #[cfg(unix)]
-    use crate::reporter::events::AbortStatus;
+    use crate::reporter::events::{AbortStatus, SIGTERM};
     use crate::{
         errors::{ChildError, ChildFdError, ChildStartError, ErrorList},
-        test_output::ChildSplitOutput,
+        reporter::events::{ChildExecutionOutputDescription, ExecutionResult, FailureStatus},
+        test_output::{ChildExecutionOutput, ChildOutput, ChildSplitOutput},
     };
     use bytes::Bytes;
     use std::{io, sync::Arc};
@@ -519,7 +523,8 @@ mod tests {
                         output: Bytes::from("stdout\nstderr").into(),
                     },
                     errors: None,
-                },
+                }
+                .into(),
                 store_stdout_stderr: true,
                 message: None,
                 description: None,
@@ -535,7 +540,8 @@ mod tests {
                         output: Bytes::from("stdout\nstderr").into(),
                     },
                     errors: None,
-                },
+                }
+                .into(),
                 store_stdout_stderr: false,
                 message: None,
                 description: None,
@@ -552,7 +558,8 @@ mod tests {
                         stderr: Some(Bytes::from("stderr").into()),
                     }),
                     errors: None,
-                },
+                }
+                .into(),
                 store_stdout_stderr: true,
                 message: None,
                 description: None,
@@ -577,7 +584,8 @@ mod tests {
                         .into(),
                     },
                     errors: None,
-                },
+                }
+                .into(),
                 store_stdout_stderr: true,
                 message: Some("thread 'foo' panicked at xyz.rs:40"),
                 description: Some("thread 'foo' panicked at xyz.rs:40:\nstrange\nextra\nextra2"),
@@ -606,7 +614,8 @@ mod tests {
                         ),
                     }),
                     errors: None,
-                },
+                }
+                .into(),
                 store_stdout_stderr: false,
                 message: Some("thread 'foo' panicked at xyz.rs:40"),
                 description: Some(
@@ -622,9 +631,7 @@ mod tests {
                 status: TestCaseStatus::non_success(NonSuccessKind::Failure),
                 output: ChildExecutionOutput::Output {
                     result: Some(ExecutionResult::Fail {
-                        failure_status: FailureStatus::Abort(AbortStatus::UnixSignal(
-                            libc::SIGTERM,
-                        )),
+                        failure_status: FailureStatus::Abort(AbortStatus::UnixSignal(SIGTERM)),
                         leaked: false,
                     }),
                     output: ChildOutput::Split(ChildSplitOutput {
@@ -632,7 +639,8 @@ mod tests {
                         stderr: None,
                     }),
                     errors: None,
-                },
+                }
+                .into(),
                 store_stdout_stderr: true,
                 message: Some("process aborted with signal 15 (SIGTERM)"),
                 description: Some("process aborted with signal 15 (SIGTERM)"),
@@ -645,9 +653,7 @@ mod tests {
                 status: TestCaseStatus::non_success(NonSuccessKind::Failure),
                 output: ChildExecutionOutput::Output {
                     result: Some(ExecutionResult::Fail {
-                        failure_status: FailureStatus::Abort(AbortStatus::UnixSignal(
-                            libc::SIGTERM,
-                        )),
+                        failure_status: FailureStatus::Abort(AbortStatus::UnixSignal(SIGTERM)),
                         leaked: true,
                     }),
                     output: ChildOutput::Split(ChildSplitOutput {
@@ -662,7 +668,8 @@ mod tests {
                             io::Error::other("huh"),
                         )))],
                     ),
-                },
+                }
+                .into(),
                 store_stdout_stderr: false,
                 message: Some("3 errors occurred executing test"),
                 description: Some(indoc::indoc! {"
@@ -696,7 +703,8 @@ mod tests {
                             io::Error::other("stdout error"),
                         )))],
                     ),
-                },
+                }
+                .into(),
                 store_stdout_stderr: false,
                 message: Some("2 errors occurred executing test"),
                 description: Some(indoc::indoc! {"
@@ -714,7 +722,8 @@ mod tests {
                 status: TestCaseStatus::non_success(NonSuccessKind::Error),
                 output: ChildExecutionOutput::StartError(ChildStartError::Spawn(Arc::new(
                     io::Error::other("start error"),
-                ))),
+                )))
+                .into(),
                 store_stdout_stderr: true,
                 message: Some("error spawning child process"),
                 description: Some(indoc::indoc! {"
@@ -763,7 +772,7 @@ mod tests {
     struct ExecuteStatusPropsCase<'a> {
         comment: &'a str,
         status: TestCaseStatus,
-        output: ChildExecutionOutput,
+        output: ChildExecutionOutputDescription<ChildSingleOutput>,
         store_stdout_stderr: bool,
         message: Option<&'a str>,
         description: Option<&'a str>,
